@@ -7,7 +7,7 @@ from .test_compatible_exe import run
 
 def test_runtests_failure(tmp_path):
     testfile = tmp_path / "test.py"
-    testcode = u"""
+    testcode = """
     def test_THIS_TEST_MUST_FAIL():
         assert False
     """
